ChangeSet 1.1276.1.42, 2003/08/27 15:01:10-07:00, david-b@pacbell.net

[PATCH] USB: Add Kconfig option for building ax8817x support in usbnet

David T Hollis wrote:
> This patch adds support to Kconfig to build ax8817x support into
> usbnet.  This renames the config option for the existing standalone
> ax8817x driver to CONFIG_USB_AX8817X_STANDALONE.

Please merge this version instead.  It includes all of David's
patch, plus it makes the descriptive info match the updated
role of this driver.  So given this, only the webpage still
needs updates; the in-tree docs are now consistent.


 drivers/usb/net/Kconfig      |   41 +++++++++++++++++++++++++++++++++++------
 drivers/usb/net/Makefile.mii |    1 +
 2 files changed, 36 insertions(+), 6 deletions(-)


diff -Nru a/drivers/usb/net/Kconfig b/drivers/usb/net/Kconfig
--- a/drivers/usb/net/Kconfig	Tue Sep  2 12:43:59 2003
+++ b/drivers/usb/net/Kconfig	Tue Sep  2 12:43:59 2003
@@ -7,7 +7,7 @@
 comment "Networking support is needed for USB Networking device support"
 	depends on USB && !NET
 
-config USB_AX8817X
+config USB_AX8817X_STANDALONE
 	tristate "USB ASIX AX8817X Ethernet device support (EXPERIMENTAL)"
 	depends on USB && NET && EXPERIMENTAL
 	---help---
@@ -121,15 +121,15 @@
 	  module, say M here and read <file:Documentation/modules.txt>.
 
 config USB_USBNET
-	tristate "Host-to-Host Networking for Cables and Smart Devices"
+	tristate "Multi-purpose USB Networking Framework"
 	depends on USB && NET
 	---help---
 	  This driver supports several kinds of network links over USB,
 	  with "minidrivers" built around a common network driver core
-	  that supports deep queues for efficient transfers.
-
-	  Typically, these links involves only two network hosts.  The
-	  host runs "usbnet", and the other end of the link might be:
+	  that supports deep queues for efficient transfers.  (This gives
+	  better performance with small packets and at high speeds).
+	  
+	  The USB host runs "usbnet", and the other end of the link might be:
 
 	  - Another USB host, when using USB "network" or "data transfer"
 	    cables.  These are often used to network laptops to PCs, like
@@ -141,6 +141,9 @@
 	    others), and devices that interoperate using the standard
 	    CDC-Ethernet specification (including many cable modems).
 
+	  - Network adapter hardware (like those for 10/100 Ethernet) which
+	    uses this driver framework.
+
 	  The link will appear with a name like "usb0", when the link is
 	  a two-node link, or "eth0" for most CDC-Ethernet devices.  Those
 	  two-node links are most easily managed with Ethernet Bridging
@@ -265,4 +268,30 @@
 	  what other networking devices you have in use.  However, if the
 	  IEEE 802 "local assignment" bit is set in the address, a "usbX"
 	  name is used instead.
+
+comment "USB Network Adapters"
+	depends on USB_USBNET
+
+config USB_AX8817X
+	boolean "ASIX AX88172 Based USB 2.0 Ethernet Devices"
+	depends on USB_USBNET && EXPERIMENTAL
+	default y
+	help
+
+	  This option adds support for ASIX AX88172 based USB 2.0
+	  10/100 Ethernet devices.
+
+ 	  This driver should work with at least the following devices:
+	    * ASIX AX88172
+	    * D-Link DUB-E100
+	    * Hawking UF200
+	    * Linksys USB200M
+	    * Netgear FA120
+	    * Intellinet
+	    * ST Lab USB Ethernet
+	    * TrendNet TU2-ET100
+
+	  This driver creates an interface named "ethX", where X depends on
+	  what other networking devices you have in use.  
+
 
diff -Nru a/drivers/usb/net/Makefile.mii b/drivers/usb/net/Makefile.mii
--- a/drivers/usb/net/Makefile.mii	Tue Sep  2 12:43:59 2003
+++ b/drivers/usb/net/Makefile.mii	Tue Sep  2 12:43:59 2003
@@ -4,3 +4,4 @@
 
 obj-$(CONFIG_USB_AX8817X)	+= mii.o
 obj-$(CONFIG_USB_PEGASUS)	+= mii.o
+obj-$(CONFIG_USB_USBNET)	+= mii.o
